==> tuia-explore-center-api-0.0.1-20190529.120309-28-sources.jar: cn/tuia/explore/center/api/dto/rsp/ReplyDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import cn.tuia.explore.center.api.dto.req.ReplyReqDto;

import java.util.List;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: ReplyDto.java , v 0.1 2019-05-24 15:46 ElinZhou Exp $
 */
public class ReplyDto extends ReplyReqDto {
    private static final long serialVersionUID = 8826184159484147522L;

    /**
     * 被评论用户的userid
     */
    private Long replyUser;

    /**
     * 子评论数量
     */
    private Long subReplyCount;

    /**
     * 点赞次数
     */
    private Long likeCount;

    /**
     * 是否点过赞
     */
    private boolean liked;

    /**
     * 头像url
     */
    private String headImage;

    /**
     * 评论者昵称
     */
    private String nickName;

    private List<ReplyDto> subComment;

    public List<ReplyDto> getSubComment() {
        return subComment;
    }

    public void setSubComment(List<ReplyDto> subComment) {
        this.subComment = subComment;
    }

    public Long getReplyUser() {
        return replyUser;
    }

    public void setReplyUser(Long replyUser) {
        this.replyUser = replyUser;
    }

    public Long getSubReplyCount() {
        return subReplyCount;
    }

    public void setSubReplyCount(Long subReplyCount) {
        this.subReplyCount = subReplyCount;
    }

    public boolean isLiked() {
        return liked;
    }

    public void setLiked(boolean liked) {
        this.liked = liked;
    }

    public Long getLikeCount() {
        return likeCount;
    }

    public void setLikeCount(Long likeCount) {
        this.likeCount = likeCount;
    }

    public String getHeadImage() {
        return headImage;
    }

    public void setHeadImage(String headImage) {
        this.headImage = headImage;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }
}

==> tuia-explore-center-api-0.0.1-20190530.115859-41-sources.jar: cn/tuia/explore/center/api/dto/rsp/ReplyDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import cn.tuia.explore.center.api.dto.req.ReplyReqDto;

import java.util.Date;
import java.util.List;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: ReplyDto.java , v 0.1 2019-05-24 15:46 ElinZhou Exp $
 */
public class ReplyDto extends ReplyReqDto {
    private static final long serialVersionUID = 8826184159484147522L;

    /**
     * 被评论用户的userid
     */
    private Long replyUser;

    /**
     * 子评论数量
     */
    private Long subReplyCount;

    /**
     * 点赞次数
     */
    private Long likeCount;

    /**
     * 是否点过赞
     */
    private boolean liked;

    /**
     * 头像url
     */
    private String headImage;

    /**
     * 评论者昵称
     */
    private String nickName;

    /**
     * 发布时间
     */
    private Date gmtCreate;

    private List<ReplyDto> subComment;

    public List<ReplyDto> getSubComment() {
        return subComment;
    }

    public void setSubComment(List<ReplyDto> subComment) {
        this.subComment = subComment;
    }

    public Long getReplyUser() {
        return replyUser;
    }

    public void setReplyUser(Long replyUser) {
        this.replyUser = replyUser;
    }

    public Long getSubReplyCount() {
        return subReplyCount;
    }

    public void setSubReplyCount(Long subReplyCount) {
        this.subReplyCount = subReplyCount;
    }

    public boolean isLiked() {
        return liked;
    }

    public void setLiked(boolean liked) {
        this.liked = liked;
    }

    public Long getLikeCount() {
        return likeCount;
    }

    public void setLikeCount(Long likeCount) {
        this.likeCount = likeCount;
    }

    public String getHeadImage() {
        return headImage;
    }

    public void setHeadImage(String headImage) {
        this.headImage = headImage;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
}
